summaryrefslogtreecommitdiff
path: root/pkg
diff options
context:
space:
mode:
Diffstat (limited to 'pkg')
-rwxr-xr-xpkg/osx/install/install-leapc.sh4
-rwxr-xr-xpkg/postmkvenv.sh2
2 files changed, 3 insertions, 3 deletions
diff --git a/pkg/postmkvenv.sh b/pkg/postmkvenv.sh
index 2f0cba45..04f8d372 100755
--- a/pkg/postmkvenv.sh
+++ b/pkg/postmkvenv.sh
@@ -16,7 +16,7 @@ elif [[ "$unamestr" == 'Darwin' ]]; then
platform='darwin'
fi
-LIBS=( PySide )
+LIBS=( PySide pysideuic )
PYTHON_VERSION=python$(python -c "import sys; print (str(sys.version_info[0])+'.'+str(sys.version_info[1]))")
VAR=( $(which -a $PYTHON_VERSION) )
diff --git a/pkg/osx/install/install-leapc.sh b/pkg/osx/install/install-leapc.sh
index ec3c2834..e47abb7c 100755
--- a/pkg/osx/install/install-leapc.sh
+++ b/pkg/osx/install/install-leapc.sh
@@ -1,6 +1,6 @@
#!/bin/bash
# LEAP CLient Installer Script.
#
# Copyright (C) 2013 LEAP Encryption Access Project
#
@@ -20,7 +20,7 @@ leapdir=/Applications/LEAP\ Client.app
leaplibs=${leapdir}/Contents/MacOS
tunstartup=/Library/StartupItems/tun/tun
-echo "Installing LEAP Client in /Applications..."
+echo "Installing Bitmask in /Applications..."
cp -r "LEAP Client.app" /Applications
echo "Copying openvpn binary..."
@@ -1,6 +1,6 @@
#!/bin/bash
-# LEAP CLient Installer Script.
+# Bitmask Installer Script.
#
# Copyright (C) 2013 LEAP Encryption Access Project